<?php

/*************************************************************************
 * Username Change - XenConcept (c) 2017
 * All Rights Reserved.
 **************************************************************************
 * This file is subject to the terms and conditions defined in the Licence
 * Agreement available at Try it like it buy it :)
 *************************************************************************/

namespace XenConcept\UsernameChange\ApprovalQueue;

use XF\ApprovalQueue\AbstractHandler;
use XF\Entity\ApprovalQueue;
use XF\Mvc\Entity\Entity;

class UsernameChange extends AbstractHandler
{

    public function getEntityWith()
    {
        return ['User'];
    }

    public function getTemplateData(ApprovalQueue $unapprovedItem)
    {
        $templateData = parent::getTemplateData($unapprovedItem);

        /** @var \XF\Entity\User $user */
        $user = $unapprovedItem->Content->User;
        $templateData['user'] = $user;

        /** @var \XenConcept\UsernameChange\Repository\ChangeLog $changeRepo */
        $changeRepo   = \XF::repository('XenConcept\UsernameChange:ChangeLog');
        $changeFinder = $changeRepo->findChangeLogsByContent($user->user_id);

        $changeLogs = $changeFinder->fetch(5);

        $templateData['changeLogs'] = $changeLogs;

        return $templateData;
    }

    public function getTemplateName()
    {
        return 'public:xc_username_change_approval_item';
    }

    public function actionApprove(\XenConcept\UsernameChange\Entity\ChangeLog $changeLog)
    {
        $changeLog->change_state = 'visible';
        $changeLog->save();

        /** @var \XF\Repository\UserAlert $alertRepo */
        $alertRepo = \XF::repository('XF:UserAlert');
        $alertRepo->fastDeleteAlertsForContent('xc_username_change', $changeLog->log_id);

        $notify = $this->getInput('notify', $changeLog->log_id);
        if ($notify)
        {
            $alertRepo->alert($changeLog->User, 0, '', 'xc_username_change', $changeLog->log_id, 'approve');
        }
    }

    public function actionReject(\XenConcept\UsernameChange\Entity\ChangeLog $changeLog)
    {
        $notify = $this->getInput('notify', $changeLog->log_id);
        $reason = $this->getInput('reason', $changeLog->log_id);

        /** @var \XF\Repository\UserAlert $alertRepo */
        $alertRepo = \XF::repository('XF:UserAlert');

        $user = $changeLog->User;

        $alertRepo->fastDeleteAlertsForContent('xc_username_change', $changeLog->log_id);

        $changeLog->delete();
        if ($notify)
        {
            $alertRepo->alert($user, 0, '', 'user', $changeLog->log_id, 'username_rejected', ['reason' => $reason]);
        }
    }
}