<?php

/*************************************************************************
 * Username Change - XenConcept (c) 2017
 * All Rights Reserved.
 **************************************************************************
 * This file is subject to the terms and conditions defined in the Licence
 * Agreement available at Try it like it buy it :)
 *************************************************************************/

namespace XenConcept\UsernameChange\Service\User;

use XF\Service\AbstractService;

class UsernameChange extends AbstractService
{
    use \XF\Service\ValidateAndSavableTrait;

    /**
     * @var \XenConcept\UsernameChange\XF\Entity\User
     */
    protected $user;

    /**
     * @var \XenConcept\UsernameChange\Entity\ChangeLog
     */
    protected $changeLog;

    public function __construct(\XF\App $app, \XF\Entity\User $user)
    {
        parent::__construct($app);

        $this->user = $user;

        $this->setupDefault();
    }

    protected function setupDefault()
    {
        $this->changeLog = $this->em()->create('XenConcept\UsernameChange:ChangeLog');

        $this->changeLog->user_id      = $this->user->user_id;
        $this->changeLog->old_username = $this->user->username;
    }

    public function getChangeLog()
    {
        return $this->changeLog;
    }

    protected function _validate()
    {
        $changeLog = $this->changeLog;

        /** @var \XF\Validator\Username $validator */
        $validator = $this->app->validator('Username');
        $changeLog->new_username = $validator->coerceValue($changeLog->new_username);

        if (!$validator->isValid($changeLog->new_username, $error))
        {
            return [
                $validator->getPrintableErrorValue($error)
            ];
        }

        $user = $this->user;
        $messageRequired = $user->getNumberOfPostsToChangeTheUsername();

        if ($messageRequired > $user->message_count)
        {
            $changeLog->error(\XF::phraseDeferred('xc_username_change_you_must_have_x_posts_currently_you_have_x_posts', [
                'messageRequired' => $messageRequired,
                'currentMessage'  => $user->message_count
            ]));
        }

        $daysBetweenChange = $user->getDaysBetweenChange();

        if ($daysBetweenChange != -1 || $daysBetweenChange != 0)
        {
            if (\XF::$time < $user->last_username_change + 86400 * $daysBetweenChange)
            {
                $changeLog->error(\XF::phraseDeferred('xc_username_change_you_must_wait_x_days', ['daysBetweenChange' => $daysBetweenChange]));
            }
        }

        if ($changeLog->new_username == $changeLog->old_username)
        {
            $changeLog->error(\XF::phraseDeferred('xc_username_change_please_enter_a_different_username'));
        }

        $changeLog->preSave();
        $errors = $changeLog->getErrors();

        return $errors;
    }

    protected function _save()
    {
        $changeLog = $this->changeLog;

        $changeLog->save(true, false);

        return $changeLog;
    }
}