<?php

/*************************************************************************
 * Username Change - XenConcept (c) 2017
 * All Rights Reserved.
 **************************************************************************
 * This file is subject to the terms and conditions defined in the Licence
 * Agreement available at Try it like it buy it :)
 *************************************************************************/

namespace XenConcept\UsernameChange\XF\Admin\Controller;

use XF\Mvc\ParameterBag;

class Log extends XFCP_Log
{

    public function actionUsernameChange()
    {

        if ($username = $this->filter('username', 'str'))
        {
            $limitUser = $this->em()->findOne('XF:User', ['username' => $username]);
            if (!$limitUser)
            {
                return $this->error(\XF::phrase('requested_user_not_found'));
            }
        }
        else
        {
            $limitUser = null;
        }

        $changeLogRepo = $this->getUsernameChangeLogRepo();
        $changeLogFinder = $changeLogRepo->findChangeLogsForList();

        $totalChanges = $changeLogFinder->total();

        if ($limitUser)
        {
            $changeLogFinder
                ->where('user_id', $limitUser->user_id);
        }

        $viewParams = [

            'entries' => $changeLogFinder->fetch(),
            'totalChanges' => $totalChanges,
            'total'   => $changeLogFinder->total()

        ];

        return $this->view('XF:Log\UsernameChangeLog\Listing', 'xc_username_change_log_username_change_list', $viewParams);
    }

    public function actionUsernameChangeClear()
    {
        if ($this->isPost())
        {
            $this->getUsernameChangeLogRepo()->clearLog();

            return $this->redirect($this->buildLink('logs/username-change'));
        }
        else
        {
            return $this->view('XF:Log\UsernameChange\Clear', 'xc_username_change_log_username_change_clear');
        }
    }

    public function actionUsernameChangeDelete(ParameterBag $params)
    {
        $entry = $this->assertUsernameChangeLogExists($params->log_id);

        if ($this->isPost())
        {
            $entry->delete();

            return $this->redirect($this->buildLink('logs/username-change'));
        }
        else
        {
            $viewParams = [
                'entry' => $entry
            ];
            return $this->view('XF:Log\UsernameChange\Delete', 'xc_username_change_log_username_change_delete', $viewParams);
        }
    }

    /**
     * @param string $id
     * @param array|string|null $with
     * @param null|string $phraseKey
     *
     * @return \XenConcept\UsernameChange\Entity\ChangeLog
     */
    protected function assertUsernameChangeLogExists($id, $with = null, $phraseKey = null)
    {
        return $this->assertRecordExists('XenConcept\UsernameChange:ChangeLog', $id, $with, $phraseKey);
    }

    /**
     * @return \XenConcept\UsernameChange\Repository\ChangeLog
     */
    protected function getUsernameChangeLogRepo()
    {
        return $this->repository('XenConcept\UsernameChange:ChangeLog');
    }
}